widgetmachine library

Classes

ChildWidgetMachine<Input, Output>
An abstract class that describes a machine connected to the flutter widget.
ControllerOutput<Internal, External>
ControllerWidget<S, Event, Internal, External>
ControllerWidgetResult<State, Internal, External>
ParentWidgetMachine<Input, Output>
An abstract class that describes an intermediate widget machine that passes input from its parent to the child, and its output from the child to the parent.
ProcessItem<Input, Output>
WidgetMachine<Input, Output>
A general class that describes a type that represents a machine object which connects to flutter widgets. Exists for implementation purposes, and must not be inherited from directly.

Extensions

ControllerWidgetStream on BuildContext
MapWidgetMachine on WidgetMachine<Input, Output>
An operator that allows to transform an internal machine in any way

Functions

runRootMachine<Input, Output>({required WidgetMachine<Input, Output> root, Handler<Output>? callback}) → void
Starts the application flow.