ChildWidgetMachine<Input, Output> class
abstract
An abstract class that describes a machine connected to the flutter widget.
- Inheritance
-
- Object
- WidgetMachine<
Input, Output> - ChildWidgetMachine
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
child(
) → Widget - A method that returns a Widget object that the machine connects to. All the input is passed into widget's MachineConsumer and all the output from widget are passed to the parent of this machine.
-
map<
RInput, ROutput> (Mapper< Machine< mapper) → WidgetMachine<Input, Output> , Machine<RInput, ROutput> >RInput, ROutput> -
Available on WidgetMachine<
Input, Output> , provided by the MapWidgetMachine extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited