ParentWidgetMachine<Input, Output> class
abstract
An abstract class that describes an intermediate widget machine that passes input from its parent to the child, and its output from the child to the parent.
- Inheritance
-
- Object
- WidgetMachine<
Input, Output> - ParentWidgetMachine
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
child(
) → WidgetMachine< Input, Output> - Provides a child widget machine that receives input that comes from the parent machine, and sends output.
-
map<
RInput, ROutput> (Mapper< Machine< mapper) → WidgetMachine<Input, Output> , Machine<RInput, ROutput> >RInput, ROutput> -
Available on WidgetMachine<
Input, Output> , provided by the MapWidgetMachine extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited